439aca57e3bbd783287b73ba5595e8b16f6fe1e4
max
  Wed Mar 1 09:58:56 2023 -0800
fixing a few comments in browserSetup.sh, suggested by Jorge, no redmine

diff --git src/product/installer/browserSetup.sh src/product/installer/browserSetup.sh
index 36ddcf5..5fc5ca5 100644
--- src/product/installer/browserSetup.sh
+++ src/product/installer/browserSetup.sh
@@ -1,24 +1,24 @@
 #!/bin/bash
 
 # script to install/setup dependencies for the UCSC genome browser CGIs
 # call it like this as root from a command line: bash browserInstall.sh
 
 # you can easily debug this script with 'bash -x browserInstall.sh', it 
 # will show all commands then
 
-exec > >(tee -a "${HOME}/browserInstall.log") 2>&1
+exec > >(tee -a "${HOME}/browserSetup.sh") 2>&1
 
 set -u -e -o pipefail # fail on unset vars and all errors, also in pipes
 
 # set all locale settings to English
 # searching for certain strings in command output might fail, if locale is different
 export LANG=C
 
 exitHandler() {
     if [ "$1" == "100" -o "$1" == "0" ] ; then
        exit $1 # all fine, a specific error message has already been output
     fi
 
     # somehow this script exited with an unknown type of error code
     echo Exit error $1 occurred on line $2
     echo The UCSC Genome Browser installation script exited with an error.
@@ -955,34 +955,34 @@
        # development machine + mysql only reachable from localhost = empty root pwd
        # secureMysql - not needed
        touch $APACHEDIR/ext/configOk.flag 
    fi
 
    echo2 Running $APACHEDIR/browserStartup.sh to start mysql and apache
    $APACHEDIR/browserStartup.sh
    echo2 Waiting for mysql to start
    sleep 5
 }
 
 # function for Debian-specific installation of mysql and apache
 function installDebian ()
 {
     # update repos
-    if [ ! -f /tmp/browserInstall.aptGetUpdateDone ]; then
+    if [ ! -f /tmp/browserSetup.aptGetUpdateDone ]; then
        echo2 Running apt-get update
        apt-get update
-       touch /tmp/browserInstall.aptGetUpdateDone
+       touch /tmp/browserSetup.aptGetUpdateDone
     fi
 
     echo2 Installing ghostscript and imagemagick
@@ -1,24 +1,24 @@
 
 # script to install/setup dependencies for the UCSC genome browser CGIs
-# call it like this as root from a command line: bash browserInstall.sh
+# call it like this as root from a command line: bash browserSetup.sh
 
@@ -1,24 +1,24 @@
 
-# you can easily debug this script with 'bash -x browserInstall.sh', it 
+# you can easily debug this script with 'bash -x browserSetup.sh', it 
 # will show all commands then
 
     waitKey
     # ghostscript for PDF export
     # imagemagick for the session gallery
     # r-base-core for the gtex tracks
     # python-mysqldb for hgGeneGraph
     apt-get --no-install-recommends --assume-yes install ghostscript imagemagick wget rsync r-base-core curl gsfonts
     # python-mysqldb has been removed in newer distros
     if apt-cache policy python-mysqldb | grep "Candidate: .none." > /dev/null; then 
 	    echo2 The package python-mysqldb is not available anymore. Working around it
 	    echo2 by installing python2 and MySQL-python with pip2
             apt-get install --assume-yes python2 libmysqlclient-dev python2-dev wget gcc
 	    curl https://bootstrap.pypa.io/pip/2.7/get-pip.py --output /tmp/get-pip.py